@@ -1,5 +1,5 @@
 /* Created by Ville-Petteri Makinen
-   email: ville.makinen@vipmak.net */
+   email: vpmakine@gmail.com */
 
 #include "koho.local.h"
 
@@ -19,13 +19,13 @@ Trainer::Trainer(const Matrix& codebook, const Topology& topo,
   vector<mdsize> subsizes(nunits, 0);
   for(mdsize i = 0; i < ntrain; i++)
     subsizes[nunits-(i%nunits)-1] += 1;
-
+    
   /* Create subsets. */
   (this->subsets).resize(nunits);
   for(mdsize k = 0; k < nunits; k++) {
     mdsize cap = subsizes[k];
-    mdreal rho = (exp(-5.0) - exp(-5.0*eq))/(exp(-5.0) - 1.0);
-    cap += (mdsize)(rho*(ntrain - cap - nunits));
+    mdreal w = (exp(-5.0) - exp(-5.0*eq))/(exp(-5.0) - 1.0);
+    cap += (mdsize)(w*(ntrain - cap - nunits));
     (this->subsets[k]).configure(k, cap);
   }
 
